@@ -1459,11 +1459,15 @@ Rcpp::List ai_mme_sp(const arma::sp_mat & X, const Rcpp::List & ZI,  const arma:
     if(nSs > 1){ // if there is more than one residual structure we have to calculate M in every iteration
       M = Wy.t() * Ri * Wy;
     }else{ // if there's only one residual structure
-      if(iIter == 0){ // only form M0 in the first iteration
-        M0 =  Wy.t() * Wy ; // base M matrix without G
+      if(useH == true){ 
+        M = Wy.t() * Ri * Wy;
+      }else{
+        if(iIter == 0){ // only form M0 in the first iteration
+          M0 =  Wy.t() * Wy ; // base M matrix without G
+        }
+        // then every iteration we just multiply M0 by 1/Ve
+        M = M0 * (1/arma::as_scalar(thetaResidualsVec(0))) ; // always multiply by the current 1/sigma2.e
       }
-      // then every iteration we just multiply M0 by 1/Ve
-      M = M0 * (1/arma::as_scalar(thetaResidualsVec(0))) ; // always multiply by the current 1/sigma2.e
     }
     
     arma::field<arma::sp_mat> lambda(nReAl);
@@ -1805,7 +1809,7 @@ Rcpp::List ai_mme_sp(const arma::sp_mat & X, const Rcpp::List & ZI,  const arma:
       if(thetaCUnlisted(i) == 3){
         arma::vec thetaUnlistedPlusAddScaleParam;
         if(iIter == 0){
-          thetaUnlistedPlusAddScaleParam = arma::join_cols(expectedNewTheta,addScaleParam);
+          thetaUnlistedPlusAddScaleParam = arma::join_cols(thetaUnlisted,addScaleParam); // expectedNewTheta
         }else{
           thetaUnlistedPlusAddScaleParam = arma::join_cols(monitor.col((iIter-1)),addScaleParam);
         }
@@ -1818,17 +1822,19 @@ Rcpp::List ai_mme_sp(const arma::sp_mat & X, const Rcpp::List & ZI,  const arma:
     thetaCUnlisted0(arma::find(thetaCUnlisted0 < 3)) = thetaCUnlisted0(arma::find(thetaCUnlisted0 < 3)) * 0; // we make everything zero except fully constrained
     arma::uvec constrained = arma::find((thetaCUnlisted0+sumToBoundary) > 0);
     arma::uvec unconstrained = arma::find((thetaCUnlisted0+sumToBoundary) <= 0);//arma::find(thetaCUnlisted != 3);
-    arma::mat InfMat_uu, InfMat_ff, InfMatInv_uu;
-    arma::vec dLu_uu, dLu_ff, delta_uu;
-    if(constrained.n_elem > 0){
+    arma::mat InfMat_uu, InfMat_ff, InfMat_uf, InfMatInv_uu, InfMatInv_ff;
+    arma::vec dLu_uu, dLu_ff, delta_uu, delta_ff;
+    if(constrained.n_elem > 0){   // Rcpp::Rcout << "Updates using constrained Information matrix" << arma::endl;
       InfMat_uu = InfMat(unconstrained,unconstrained);
       InfMat_ff = InfMat(constrained,constrained);
+      InfMat_uf = InfMat(unconstrained,constrained);
       dLu_uu = dLu(unconstrained);
       dLu_ff = dLu(constrained);
+      InfMatInv_ff = pinv(InfMat_ff,tolParInv);
       InfMatInv_uu = pinv(InfMat_uu,tolParInv);
-      delta_uu = InfMatInv_uu * dLu_uu;
+      delta_ff = InfMatInv_ff * dLu_ff;
+      delta_uu = InfMatInv_uu * (dLu_uu - ( InfMat_uf * (InfMatInv_ff*delta_ff) ) );
       delta(unconstrained) = delta_uu;
-      // delta(constrained) = delta(constrained) * 0;
       expectedNewTheta(unconstrained) = thetaUnlisted(unconstrained) - delta(unconstrained);
     }
     // C) quantify delta changes
@@ -1893,9 +1899,9 @@ Rcpp::List ai_mme_sp(const arma::sp_mat & X, const Rcpp::List & ZI,  const arma:
       arma::mat thetaCProvNew = vec_to_matCpp(thetaCUnlisted(toFill), thetaC[i] );
       thetaC(i) = thetaCProvNew;
     }
-   // #######################
-   // # 9) Stopping criteria
-   // #######################
+    // #######################
+    // # 9) Stopping criteria
+    // #######################
     // get current time
     time_t now = time(0);
     tm *ltm = localtime(&now);
@@ -1954,7 +1960,7 @@ Rcpp::List ai_mme_sp(const arma::sp_mat & X, const Rcpp::List & ZI,  const arma:
     Rcpp::Named("u") = u,
     Rcpp::Named("bu") = bu,
     Rcpp::Named("Ci") = Ci,
-    Rcpp::Named("avInf") = InfMat,
+    Rcpp::Named("avInf") = avInf, //InfMat,
     Rcpp::Named("monitor") = monitor,
     Rcpp::Named("constraints") = thetaCUnlistedFinal, 
     Rcpp::Named("AIC") = AIC,
